pub struct Scroll { /* private fields */ }Expand description
A scroll view
Implementations
Sourceimpl Scroll
impl Scroll
Sourcepub fn ensure_visible(self, to: impl Fn() -> Rect + 'static) -> Scroll
pub fn ensure_visible(self, to: impl Fn() -> Rect + 'static) -> Scroll
Ensures that a specific rectangular area is visible within the scroll view by automatically scrolling to it if necessary.
Reactivity
The viewport will automatically update to include the target rectangle whenever the rectangle’s
position or size changes, as determined by the to function which will update any time there are
changes in the signals that it depends on.
Sourcepub fn scroll_delta(self, delta: impl Fn() -> Vec2 + 'static) -> Scroll
pub fn scroll_delta(self, delta: impl Fn() -> Vec2 + 'static) -> Scroll
Scrolls the view by the specified delta vector.
Reactivity
The scroll position will automatically update whenever the delta vector changes,
as determined by the delta function which will update any time there are changes in the signals that it depends on.
Sourcepub fn scroll_to(self, origin: impl Fn() -> Option<Point> + 'static) -> Scroll
pub fn scroll_to(self, origin: impl Fn() -> Option<Point> + 'static) -> Scroll
Scrolls the view to the specified target point.
Reactivity
The scroll position will automatically update whenever the target point changes,
as determined by the origin function which will update any time there are changes in the signals that it depends on.
Sourcepub fn scroll_to_percent(self, percent: impl Fn() -> f32 + 'static) -> Scroll
pub fn scroll_to_percent(self, percent: impl Fn() -> f32 + 'static) -> Scroll
Scrolls the view to the specified percentage (0-100) of its scrollable content.
Reactivity
The scroll position will automatically update whenever the target percentage changes,
as determined by the percent function which will update any time there are changes in the signals that it depends on.
Sourcepub fn scroll_to_view(
self,
view: impl Fn() -> Option<ViewId> + 'static,
) -> Scroll
pub fn scroll_to_view( self, view: impl Fn() -> Option<ViewId> + 'static, ) -> Scroll
Scrolls the view to make a specific view visible.
Reactivity
The scroll position will automatically update whenever the target view changes,
as determined by the view function which will update any time there are changes in the signals that it depends on.
Sourceimpl Scroll
internal methods
impl Scroll
internal methods
Sourcepub fn do_ensure_visible(&mut self, rect: Rect)
pub fn do_ensure_visible(&mut self, rect: Rect)
Ensure that an entire area is visible in the scroll view.
Scrolls the minimum distance necessary to make the entire rect visible. If the rect is larger than the viewport, prioritizes showing the top-left.
Arguments
rect- The rectangle in content coordinates (relative to the child’s layout)