pub struct ScrollChanged {
pub offset: Vec2,
}Expand description
Event fired when a scroll view’s scroll position changes
This event is fired whenever the visible viewport of the scroll view changes, either through user interaction (scrolling with mouse wheel, dragging scrollbars) or programmatic changes to the scroll offset.
Fields
offset: Vec2The scroll offset as a vector (how far scrolled from origin)
Implementations
Sourceimpl ScrollChanged
impl ScrollChanged
Sourcepub fn listener() -> ScrollChangedListener
pub fn listener() -> ScrollChangedListener
Get the event listener for this custom event