pub struct ScrollCustomStyle(/* private fields */);Expand description
Represents a custom style for a Scroll.
Implementations
Sourceimpl ScrollCustomStyle
impl ScrollCustomStyle
Sourcepub fn new() -> ScrollCustomStyle
pub fn new() -> ScrollCustomStyle
Creates a new ScrollCustomStyle.
Sourcepub fn shrink_to_fit(self) -> ScrollCustomStyle
pub fn shrink_to_fit(self) -> ScrollCustomStyle
Configures the scroll view to allow the viewport to be smaller than the inner content, while still taking up the full available space in its container.
Use this when you need a scroll view that can shrink its viewport size to fit within the container, ensuring the content remains scrollable even if the inner content is greater than the parent size.
Internally this does a s.min_size(0., 0.).size_full().
Sourcepub fn handle_background(self, color: impl Into<Brush>) -> ScrollCustomStyle
pub fn handle_background(self, color: impl Into<Brush>) -> ScrollCustomStyle
Sets the background color for the handle.
Sourcepub fn handle_border_radius(
self,
border_radius: impl Into<Length>,
) -> ScrollCustomStyle
pub fn handle_border_radius( self, border_radius: impl Into<Length>, ) -> ScrollCustomStyle
Sets the border radius for the handle.
Sourcepub fn handle_border_color(
self,
border_color: impl Into<Brush>,
) -> ScrollCustomStyle
pub fn handle_border_color( self, border_color: impl Into<Brush>, ) -> ScrollCustomStyle
Sets the border color for the handle.
Sourcepub fn handle_border(self, border: impl Into<Pt>) -> ScrollCustomStyle
pub fn handle_border(self, border: impl Into<Pt>) -> ScrollCustomStyle
Sets the border thickness for the handle.
Sourcepub fn handle_rounded(self, rounded: impl Into<bool>) -> ScrollCustomStyle
pub fn handle_rounded(self, rounded: impl Into<bool>) -> ScrollCustomStyle
Sets whether the handle should have rounded corners.
Sourcepub fn track_background(self, color: impl Into<Brush>) -> ScrollCustomStyle
pub fn track_background(self, color: impl Into<Brush>) -> ScrollCustomStyle
Sets the background color for the track.
Sourcepub fn track_border_radius(
self,
border_radius: impl Into<Length>,
) -> ScrollCustomStyle
pub fn track_border_radius( self, border_radius: impl Into<Length>, ) -> ScrollCustomStyle
Sets the border radius for the track.
Sourcepub fn track_border_color(
self,
border_color: impl Into<Brush>,
) -> ScrollCustomStyle
pub fn track_border_color( self, border_color: impl Into<Brush>, ) -> ScrollCustomStyle
Sets the border color for the track.
Sourcepub fn track_border(self, border: impl Into<Pt>) -> ScrollCustomStyle
pub fn track_border(self, border: impl Into<Pt>) -> ScrollCustomStyle
Sets the border thickness for the track.
Sourcepub fn track_rounded(self, rounded: impl Into<bool>) -> ScrollCustomStyle
pub fn track_rounded(self, rounded: impl Into<bool>) -> ScrollCustomStyle
Sets whether the track should have rounded corners.
Sourcepub fn vertical_track_inset(self, inset: impl Into<Pt>) -> ScrollCustomStyle
pub fn vertical_track_inset(self, inset: impl Into<Pt>) -> ScrollCustomStyle
Sets the vertical track inset.
Sourcepub fn horizontal_track_inset(self, inset: impl Into<Pt>) -> ScrollCustomStyle
pub fn horizontal_track_inset(self, inset: impl Into<Pt>) -> ScrollCustomStyle
Sets the horizontal track inset.
Sourcepub fn hide_bars(self, hide: impl Into<bool>) -> ScrollCustomStyle
pub fn hide_bars(self, hide: impl Into<bool>) -> ScrollCustomStyle
Controls the visibility of the scroll bars.
Sourcepub fn propagate_pointer_wheel(
self,
propagate: impl Into<bool>,
) -> ScrollCustomStyle
pub fn propagate_pointer_wheel( self, propagate: impl Into<bool>, ) -> ScrollCustomStyle
Sets whether the pointer wheel events should be propagated.
Sourcepub fn vertical_scroll_as_horizontal(
self,
vert_as_horiz: impl Into<bool>,
) -> ScrollCustomStyle
pub fn vertical_scroll_as_horizontal( self, vert_as_horiz: impl Into<bool>, ) -> ScrollCustomStyle
Sets whether vertical scrolling should be interpreted as horizontal scrolling.
Sourcepub fn show_bars_when_idle(self, show: impl Into<bool>) -> ScrollCustomStyle
pub fn show_bars_when_idle(self, show: impl Into<bool>) -> ScrollCustomStyle
Controls whether scroll bars are shown when not scrolling. When false, bars are only shown during scroll interactions.